pub struct ControlClient<T: RpcTransport = DynRpcTransport>(pub T);Expand description
Automatically generated client type that communicates to servers implementing the [ControlProtocol] protocol. The easiest way to use this is by using the From<RpcTransport> implementation.
See the [ControlProtocol] trait for further documentation on the functionality of the methods..
Tuple Fields
0: TImplementations
Sourceimpl<__nrpc_T: RpcTransport + Send + Sync + 'static> ControlClient<__nrpc_T>
impl<__nrpc_T: RpcTransport + Send + Sync + 'static> ControlClient<__nrpc_T>
pub async fn conn_info(&self) -> Result<ConnInfo, ControlError<__nrpc_T::Error>>
pub async fn stat_num( &self, stat: String, ) -> Result<f64, ControlError<__nrpc_T::Error>>
pub async fn start_time( &self, ) -> Result<SystemTime, ControlError<__nrpc_T::Error>>
pub async fn stop(&self) -> Result<(), ControlError<__nrpc_T::Error>>
pub async fn recent_logs( &self, ) -> Result<Vec<String>, ControlError<__nrpc_T::Error>>
pub async fn check_secret( &self, secret: String, ) -> Result<Result<bool, String>, ControlError<__nrpc_T::Error>>
pub async fn user_info( &self, secret: String, ) -> Result<Result<UserInfo, String>, ControlError<__nrpc_T::Error>>
pub async fn start_registration( &self, ) -> Result<Result<usize, String>, ControlError<__nrpc_T::Error>>
pub async fn poll_registration( &self, idx: usize, ) -> Result<Result<RegistrationProgress, String>, ControlError<__nrpc_T::Error>>
pub async fn convert_legacy_account( &self, username: String, password: String, ) -> Result<Result<String, String>, ControlError<__nrpc_T::Error>>
pub async fn stat_history( &self, stat: String, ) -> Result<Result<Vec<f64>, String>, ControlError<__nrpc_T::Error>>
pub async fn exit_list( &self, ) -> Result<Result<Vec<ExitDescriptor>, String>, ControlError<__nrpc_T::Error>>
pub async fn free_exit_list( &self, ) -> Result<Result<Vec<ExitDescriptor>, String>, ControlError<__nrpc_T::Error>>
pub async fn latest_news( &self, lang: String, ) -> Result<Result<Vec<NewsItem>, String>, ControlError<__nrpc_T::Error>>
pub async fn price_points( &self, ) -> Result<Result<Vec<(u32, f64)>, String>, ControlError<__nrpc_T::Error>>
pub async fn payment_methods( &self, ) -> Result<Result<Vec<String>, String>, ControlError<__nrpc_T::Error>>
pub async fn create_payment( &self, secret: String, days: u32, method: String, ) -> Result<Result<String, String>, ControlError<__nrpc_T::Error>>
pub async fn get_free_voucher( &self, secret: String, ) -> Result<Result<Option<VoucherInfo>, String>, ControlError<__nrpc_T::Error>>
pub async fn redeem_voucher( &self, secret: String, code: String, ) -> Result<Result<i32, String>, ControlError<__nrpc_T::Error>>
pub async fn export_debug_pack( &self, email: Option<String>, contents: String, ) -> Result<Result<(), String>, ControlError<__nrpc_T::Error>>
pub async fn get_update_manifest( &self, ) -> Result<Result<(Value, String), String>, ControlError<__nrpc_T::Error>>