Crate geph5_client

source ·

Modules

Structs

  • Automatically generated client type that communicates to servers implementing the [ControlProtocol] protocol. The easiest way to use this is by using the From<RpcTransport> implementation.

Enums

Functions